This repository contains the MATLAB code and dataset used in the study:
> **Karagoz, O. K., Kilic, A., Aydin, E. Y., Ankarali, M. M., & Uyanik, I.** "Predictive Uncertainty in State-Estimation Drives Active Sensing Behavior."

The code models and simulates the active sensing movements in **Eigenmannia virescens**, a weakly electric fish, using a closed-loop feedback control system that minimizes predictive uncertainty in state estimation. The included dataset provides experimental data used to validate this model.

## Repository Structure

- **`main_example.m`**: A simple example to demonstrate how to run the main code.
- **`main_results.m`**: Replicates the core results and figures presented in the paper.
- **`run_*` Scripts**: Run specific model variations explored in the study:
  - **`run_biswas.m`**: Implements the Biswas et al. (2023) semi-closed-loop model.
  - **`run_open_loop.m`**: Implements an open-loop model with random noise as active sensing.
  - **`run_predictive_uncertainty.m`**: Implements the main closed-loop model that minimizes predictive uncertainty.
- **`data/` Folder**: Contains data files from the experiments, organized by lighting conditions and frequency settings.
- **`utilities/` Folder**: Utility functions for data processing and plotting.

## Dataset

The `data/` folder contains raw experimental data in `.csv` format, structured as follows:

- **Light Conditions**: Separate folders for `light` and `dimlight` conditions.
- **Frequency Settings**: Subfolders for each frequency setting (`010Hz`, `015Hz`, and `025Hz`).
- **Data Files**: Each subfolder contains `.csv` files for different trials, named `trialX.csv`.
- **Description**: Each `.csv` file records the digitized positions of the refuge and fish, respectively, in centimeters.

## Requirements

- MATLAB (R2020b or later is recommended)
- Required Toolboxes:
  - Control System Toolbox
  - Statistics and Machine Learning Toolbox
