function cost = cost_function_predictive_uncertanity(xx,x0,step,ekf_param,params,active_sensing_form,weights,active_sensing0)

%%% input
    % xx: supplied input from optimaztion algorithm
    % x0: initial state
    % step: amount of future steps to predict
    % ekf_param: ekf parameters
    % params: parameters
    % active_sensing_form: type of active sensing
    
x = nan(length(x0),step+1);                             % initiate states
x(:,1) = x0;                                            % assign initial value
P = nan(length(x0),length(x0),step+1);                  % initiate covariance matrices
P(:,:,1) = ekf_param.P;                                 % assign initial value 
S = nan(size(ekf_param.R,1),size(ekf_param.R,2),step+1);% initiate innovation covariance
K = nan(length(x0),length(ekf_param.R),step+1);         % initiate kalman gain
t = 0:params.Ts:step*params.Ts;  
eig_vals = nan(1,step);

% closed loop A matrix, i.e. (A+BK) where A is model.A, B is model.B
A = ekf_param.F + ekf_param.L*[0 0 params.Kp params.Kd; 0 0 0 0]; 

if active_sensing_form == 0         
    [BB,AA] = butter(4,[xx(1) xx(2)],'bandpass');
    active_sensing = normrnd(0,ones(1,length(t)));
    active_sensing = xx(3)*filter(BB,AA,active_sensing);
    active_sensing = active_sensing(1:step);
elseif active_sensing_form == 1
    active_sensing = xx;    
elseif active_sensing_form == 2  
    error('not implemented yet');
elseif active_sensing_form == 3    
    [BB,AA] = butter(4,xx(1));
    active_sensing = normrnd(0,ones(1,length(t)));
    active_sensing = xx(2)*filter(BB,AA,active_sensing);
    active_sensing = active_sensing(1:step);
end

for ii = 1:step
    
    x(:,ii+1) = A*x(:,ii) + ekf_param.L*[active_sensing(:,ii);0];
    P(:,:,ii+1) = A*P(:,:,ii)*A' + ekf_param.L*ekf_param.Q*ekf_param.L';
    S(:,:,ii+1) = ekf_param.H(x(:,ii+1))*P(:,:,ii+1)*ekf_param.H(x(:,ii+1))' + ekf_param.R;   
    K(:,:,ii+1) = P(:,:,ii+1)*ekf_param.H(x(:,ii+1))'*pinv(S(:,:,ii+1));  
    P(:,:,ii+1) = (eye(length(x0))-K(:,:,ii+1)*ekf_param.H(x(:,ii+1)))*P(:,:,ii+1);
    
    eig_vals(ii) = P(3,3,ii+1);
     
end

cost = weights(1)*eig_vals(end)+weights(2)*sum(active_sensing.^2)+weights(3)*(active_sensing0-active_sensing)^2;
