function [params,model] = init_params(fish_no)

%%% general variables
params.Ts = 0.04;      % sampling time (s)
params.scene = [3 5];  % measurement model parameters (a, b)

%%% plant variables
params.m = 0.0025;      % kg
params.k = 0.2385;      % N/m 
params.b = 0.0269;      % Ns/m

% ct matricies
dummy.A = [0 1;0 -params.b/params.m]; 
dummy.B = [0;params.k/params.m];

% dt matricies
fish = c2d(ss(dummy.A,dummy.B,eye(2),zeros(2,1)),params.Ts);

% closed loop poles
if fish_no == 1
    dummy = place(fish.A,fish.B,[0.7731 + 0.2355i 0.7731 - 0.2355i]); % Fish 1
elseif fish_no == 2
    dummy = place(fish.A,fish.B,[0.7680 + 0.1453i 0.7680 - 0.1453i]); % Fish 2
elseif fish_no == 3
    dummy = place(fish.A,fish.B,[0.81 0.52]); % Fish 3
end

params.Kp = dummy(1);
params.Kd = dummy(2);

% constant velocity model for refuge
refuge.Ar = [1 params.Ts;0 1];
refuge.Br = [params.Ts^2/2;params.Ts];

% total state transtion matricies
model.A = [fish.A zeros(2,2); refuge.Ar-fish.A refuge.Ar];
model.B = [fish.B zeros(2,1);-fish.B refuge.Br];

params.p_noise = 0.01;          % process noise (variance)
params.m_noise = 0.2;           % measurement noise (variance)
params.r_noise = 0.02;          % d2r noise (variance) 

% active sensing generator parameters
params.act_params = [0 0 0]; 

% normal distribution for initial state [mu_position sigma_position mu_veloctiy sigma_velocity]
params.init_state_prob = [-0.1837 1.4452 0.6846 1.2075]; 




