clear all
addpath(genpath('./utilities'));
load('.\data\optimum_parameter_set.mat');   % optimum (best describes the fish's behavior) parameter set


%%
% active sensing type (predictive_uncertanity, open_loop, biswas)
active_sensing = {'open_loop'};
% fish no (1, 2, 3)
fish_no = 1;    
% stimuli frequency (0.10, 0.15, 0.25)
frequency = 0.25;      
% number of random realizations (monte-carlo simulation) 
N = 1000;                                   

%%
% function handle that runs simulation for selected active sensing type
f_handle = str2func(strcat('run_',char(active_sensing),'_mex')); 
% load optimum parameter for set
optimum_par = optimum_parameter_set.optimum_par(find(ismember(optimum_parameter_set(:,1:3),table(active_sensing,fish_no,frequency))),:);

% fish position data
[~,fish_p] = loadfishdata(fish_no,frequency);
% simulation model and parameters
[params,model] = init_params(fish_no);
% time and refuge trajectory 
[t,refuge] = refugeparams2trajectory(1,frequency,params);

% run simulation
rng(415837146); % give seed to control random number generator 
[x_all,xf_all,u_all,active_sensing_all,P_all] = f_handle(optimum_par,N,model,params,refuge);

%%
% plot trajectory
n_th = 1;
plot_trajectory(t(1:size(x_all,3)),reshape(x_all(n_th,:,:), [4 size(x_all,3)]),reshape(xf_all(n_th,:,:), [4 size(x_all,3)]),fish_p,reshape(P_all(n_th,:,:,:),[4 4 size(x_all,3)]),u_all(n_th,:),active_sensing_all(n_th,:),char(active_sensing))

% time to frequency
[sim_f,~] = trajectory2magfreq(reshape(x_all(:,1,:), [size(x_all,1) size(x_all,3)]),params);
[fish_f,freqaxis] = trajectory2magfreq(fish_p,params);

% plot fft
plot_fft(sim_f,fish_f,freqaxis,char(active_sensing))