function plot_fft(sim_f,fish_f,freqaxis,flag)

% bootstrap resampling
n_samples = 10;
n_bootstrap = 10000; % number of bootstrap samples
bootstrap_means = zeros(n_bootstrap, size(fish_f,2)); % to store means of each bootstrap sample

for i = 1:n_bootstrap
    bootstrap_sample = fish_f(randsample(n_samples, n_samples, true), :); % resample with replacement
    bootstrap_means(i,:) = mean(bootstrap_sample);
end

% Compute 95% Confidence Interval
alpha = 0.05; % for 95% CI
fish_f_min = quantile(bootstrap_means, alpha/2);
fish_f_max = quantile(bootstrap_means, 1-alpha/2);


fish_f_med = mean(fish_f);
sim_f_med = mean(sim_f,1);

h = figure('Renderer', 'painters','Units','centimeters');
hold on;
patch([freqaxis fliplr(freqaxis)], [fish_f_min fliplr(fish_f_max)],[0 130/255 200/255],'FaceAlpha',0.15, 'EdgeColor','none')
plot(freqaxis,fish_f_med,'Color',[0 130/255 200/255],'Linewidth',2);
if  strcmp(flag,'predictive_uncertanity')
    plot(freqaxis,sim_f_med,'Color',[245/255 130/255 48/255],'Linewidth',2);
elseif strcmp(flag,'open_loop')
    plot(freqaxis,sim_f_med,'Color',[0.4660 0.6740 0.1880],'Linewidth',2);
elseif strcmp(flag,'biswas')
    plot(freqaxis,sim_f_med,'Color',[145/255,30/255,180/255],'Linewidth',2);
end

hold off;

box on;

set(gca,'xscale','log')
set(gca,'yscale','log')

xticks([0.1 0.2 0.5 1])
xticklabels({'0.1','0.2','0.5','1'})
yticks([0.01 0.1 1])
yticklabels({'0.01','0.1','1'})
ylim([0.005 1.95])

ax = gca; 
ax.FontSize = 7; 

legend('95% confidence interval for fish','fish mean',strcat(strrep(flag,"_"," "),' mean'),'FontSize',8,'FontName','Helvetica','Location','best');
legend boxoff

xlabel('frequency [Hz]','FontSize',8,'FontName','Helvetica');
ylabel('magnitude [cm]','FontSize',8,'FontName','Helvetica');
    

fig_prop = get(h);
set(h,"Position",[10 10 9 fig_prop.Position(4)*9/fig_prop.Position(3)/2])